@@ -370,7 +370,15 @@ static int tcp_tl_set_fdset(struct eXosip_t *excontext, fd_set *osip_fdset, fd_s
 
 #endif
 
+
   for (pos = 0; pos < EXOSIP_MAX_SOCKETS; pos++) {
+
+    if (reserved->socket_tab[pos].invalid > 0) {
+      OSIP_TRACE(osip_trace(__FILE__, __LINE__, OSIP_ERROR, NULL, "[eXosip] [TCP] [fdset] socket info:[%s][%d] [sock=%d] [pos=%d] manual reset\n", reserved->socket_tab[pos].remote_ip, reserved->socket_tab[pos].remote_port, reserved->socket_tab[pos].socket, pos));
+      _tcp_tl_close_sockinfo(&reserved->socket_tab[pos]);
+      continue;
+    }
+
     if (reserved->socket_tab[pos].socket > 0) {
       if (osip_fdset != NULL)
         eXFD_SET(reserved->socket_tab[pos].socket, osip_fdset);
@@ -677,7 +685,7 @@ static int _tcp_read_tcp_main_socket(struct eXosip_t *excontext) {
       int res;
 
       memset(&ev, 0, sizeof(struct epoll_event));
-      ev.events = EPOLLIN | EPOLLOUT;
+      ev.events = EPOLLIN;
       ev.data.fd = sock;
       res = epoll_ctl(excontext->epfd, EPOLL_CTL_ADD, sock, &ev);
 
@@ -1731,6 +1739,15 @@ static int tcp_tl_send_message(struct eXosip_t *excontext, osip_transaction_t *t
       port = 5060;
   }
 
+  for (pos = 0; pos < EXOSIP_MAX_SOCKETS; pos++) {
+    if (reserved->socket_tab[pos].invalid > 0) {
+      OSIP_TRACE(osip_trace(__FILE__, __LINE__, OSIP_ERROR, NULL, "[eXosip] [TCP] [send] socket info:[%s][%d] [sock=%d] [pos=%d] manual reset\n", reserved->socket_tab[pos].remote_ip, reserved->socket_tab[pos].remote_port,
+                            reserved->socket_tab[pos].socket, pos));
+      _tcp_tl_close_sockinfo(&reserved->socket_tab[pos]);
+      continue;
+    }
+  }
+
   i = _tl_resolv_naptr_destination(excontext, tr, sip, &host, &port, &naptr_record);
   if (i == OSIP_SUCCESS + 1)
     return i;
