@@ -229,10 +229,16 @@ static void __osip_trace_func(const char *fi, int li, osip_trace_level_t level,
       char *tmp = strstr(buffer, "socket [");
       add_log(LOG_ERR, tmp);
 
-    } else if (strstr(buffer, "[ssl connect] succeeded") != NULL) {
-      char *tmp = strstr(buffer, "[ssl connect] succeeded");
+    } else if (strstr(buffer, "[ssl connect] [verification=") != NULL) {
+      char *tmp = strstr(buffer, "[ssl connect] ");
       add_log(LOG_INFO, tmp);
 
+      if (error_reason[0] == '\0') {
+	if (strstr(buffer, "[ssl connect] [verification=ENABLED] [FAILURE") != NULL) {
+	  snprintf(error_reason, sizeof(error_reason), "%s", tmp);
+	}
+      }
+      
     } else if (strstr(buffer, "[TLS] invalid  depth[") != NULL) {
       char *tmp = strstr(buffer, "[TLS] invalid  depth[");
       add_log(LOG_ERR, tmp);
@@ -241,14 +247,6 @@ static void __osip_trace_func(const char *fi, int li, osip_trace_level_t level,
         snprintf(error_reason, sizeof(error_reason), "%s", tmp);
       }
 
-    } else if (strstr(buffer, "[ssl connect] error") != NULL) {
-      char *tmp = strstr(buffer, "[ssl connect] error");
-      add_log(LOG_ERR, tmp);
-
-      if (error_reason[0] == '\0') {
-        snprintf(error_reason, sizeof(error_reason), "%s", tmp);
-      }
-
     } else if (strstr(buffer, "cannot connect socket ") != NULL && strstr(buffer, "terminated") != NULL) {
       char *tmp = strstr(buffer, "cannot connect socket ");
       add_log(LOG_ERR, tmp);
@@ -366,7 +364,7 @@ static int _resolv_naptr(const char *domain) {
         }
 
         osip_gettimeofday(&time_end, NULL);
-        timersub(&time_end, &time_start, &time_sub);
+        osip_timersub(&time_end, &time_start, &time_sub);
         syslog_wrapper(LOG_INFO, "NAPTR REPORT:[SUCCESS] [duration:%li,%03lis] best service for %s -> [%s] [%s:%i]", time_sub.tv_sec, time_sub.tv_usec / 1000, naptr_lookup.domain, best->protocol, best->srventry[0].srv, best->srventry[0].port);
         return 0;
       }
@@ -374,7 +372,7 @@ static int _resolv_naptr(const char *domain) {
   }
 
   osip_gettimeofday(&time_end, NULL);
-  timersub(&time_end, &time_start, &time_sub);
+  osip_timersub(&time_end, &time_start, &time_sub);
   syslog_wrapper(LOG_ERR, "NAPTR REPORT:[FAILURE] [duration:%li,%03lis] no NAPTR/no SRV record for %s", time_sub.tv_sec, time_sub.tv_usec / 1000, domain);
   return 0;
 }
@@ -779,7 +777,7 @@ int main(int argc, char *argv[]) {
     switch (event->type) {
     case EXOSIP_REGISTRATION_SUCCESS:
       osip_gettimeofday(&time_end, NULL);
-      timersub(&time_end, &time_start, &time_sub);
+      osip_timersub(&time_end, &time_start, &time_sub);
 
       dump_logs();
       syslog_wrapper(LOG_INFO, "REGISTRATION REPORT:[SUCCESS] [%s][duration:%li,%03lis] REGISTER [%i][%s]", transport, time_sub.tv_sec, time_sub.tv_usec / 1000, event->response->status_code, event->response->reason_phrase);
@@ -789,7 +787,7 @@ int main(int argc, char *argv[]) {
 
     case EXOSIP_REGISTRATION_FAILURE:
       osip_gettimeofday(&time_end, NULL);
-      timersub(&time_end, &time_start, &time_sub);
+      osip_timersub(&time_end, &time_start, &time_sub);
 
       dump_logs();
 
